############
Installation
############


************
Requirements
************

* `Django`_ 1.3 or higher. Django 1.6 or higher is recommended.
* Python 2.6 or a higher release of Python 2.x or PyPy 1.5 or higher, Python 3.3 or higher.
* For Python 2.6 you need `argparse`_

************
Installation
************


Install django-hvad using `pip`_ by running ``pip install django-hvad``. Then
add ``'hvad'`` to your ``INSTALLED_APPS`` to make the admin templates work.

.. _pip: http://pypi.python.org/pypi/pip
.. _Django: http://www.djangoproject.com
.. _django-cbv: http://pypi.python.org/pypi/django-cbv
.. _argparse: http://pypi.python.org/pypi/argparse
